/*
 * libmedia-thumbnail
 *
 * Copyright (c) 2000 - 2011 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: Hyunjun Ko <zzoon.ko@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#include "media-thumb-db.h"
#include "media-thumb-util.h"
#include "media-thumb-debug.h"

#include <glib.h>
#include <string.h>
#include <unistd.h>

int _media_thumb_get_thumb_from_db(const char *origin_path, char *thumb_path, int max_length, uid_t uid)
{
	int err = MS_MEDIA_ERR_NONE;
	char *query_string = NULL;
	sqlite3_stmt *stmt = NULL;
	MediaDBHandle *db_handle = NULL;

	thumb_retvm_if(!STRING_VALID(origin_path), MS_MEDIA_ERR_INVALID_PARAMETER, "Invalid origin_path");

	query_string = sqlite3_mprintf(SELECT_THUMB_BY_PATH, origin_path);
	thumb_retvm_if(!STRING_VALID(query_string), MS_MEDIA_ERR_OUT_OF_MEMORY, "Memory allocation is failed");
	thumb_dbg_slog("Query: %s", query_string);

	err = media_db_connect(&db_handle, uid, FALSE);
	if (err != MS_MEDIA_ERR_NONE) {
		thumb_err("media_db_connect failed: %d", err);
		db_handle = NULL;
		SQLITE3_SAFE_FREE(query_string);
		return err;
	}

	err = sqlite3_prepare_v2(db_handle, query_string, strlen(query_string), &stmt, NULL);
	SQLITE3_SAFE_FREE(query_string);
	if (SQLITE_OK != err) {
		thumb_err("prepare error [%s]", sqlite3_errmsg(db_handle));
		media_db_disconnect(db_handle);

		return MS_MEDIA_ERR_DB_INTERNAL;
	}

	if (sqlite3_step(stmt) == SQLITE_ROW) {
		SAFE_STRLCPY(thumb_path, (const char *)sqlite3_column_text(stmt, 0), max_length);
	} else {
		thumb_err("end of row [%s]", sqlite3_errmsg(db_handle));
		SQLITE3_FINALIZE(stmt);
		media_db_disconnect(db_handle);

		return MS_MEDIA_ERR_DB_INTERNAL;
	}

	SQLITE3_FINALIZE(stmt);
	media_db_disconnect(db_handle);

	thumb_retvm_if(!g_file_test(thumb_path, G_FILE_TEST_EXISTS), MS_MEDIA_ERR_INTERNAL, "thumb path doesn't exist in file system");

	return MS_MEDIA_ERR_NONE;
}

int _media_thumb_update_db(const char *origin_path, char *thumb_path, uid_t uid)
{
	int err = MS_MEDIA_ERR_NONE;
	char *query_string = NULL;

	thumb_retvm_if(!STRING_VALID(origin_path), MS_MEDIA_ERR_INVALID_PARAMETER, "Invalid origin_path");

	query_string = sqlite3_mprintf(UPDATE_THUMB_BY_PATH, thumb_path, origin_path);
	thumb_retvm_if(!STRING_VALID(query_string), MS_MEDIA_ERR_OUT_OF_MEMORY, "Memory allocation is failed");

	err = media_db_request_update_db(query_string, uid);
	SQLITE3_SAFE_FREE(query_string);

	return err;
}

